package com.ruoyi.interfaces.mapper;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.interfaces.domain.MdModelFile;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 模型文件信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Mapper
@DataSource(DataSourceType.SLAVE)
public interface MdModelFileMapper 
{
    /**
     * 查询模型文件信息
     * 
     * @param fileid 模型文件信息主键
     * @return 模型文件信息
     */
    public MdModelFile selectMdModelFileByFileid(String fileid);

    /**
     * 查询模型文件信息列表
     * 
     * @param mdModelFile 模型文件信息
     * @return 模型文件信息集合
     */
    public List<MdModelFile> selectMdModelFileList(MdModelFile mdModelFile);

    /**
     * 新增模型文件信息
     * 
     * @param mdModelFile 模型文件信息
     * @return 结果
     */
    public int insertMdModelFile(MdModelFile mdModelFile);

    /**
     * 修改模型文件信息
     * 
     * @param mdModelFile 模型文件信息
     * @return 结果
     */
    public int updateMdModelFile(MdModelFile mdModelFile);

    /**
     * 删除模型文件信息
     * 
     * @param fileid 模型文件信息主键
     * @return 结果
     */
    public int deleteMdModelFileByFileid(String fileid);

    /**
     * 批量删除模型文件信息
     * 
     * @param fileids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMdModelFileByFileids(String[] fileids);
}
