package com.ruoyi.interfaces.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.interfaces.domain.MdModelFile;
import com.ruoyi.interfaces.service.IMdModelFileService;
import com.ruoyi.interfaces.service.IMdModelInfoService;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 模型文件信息Controller
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@RestController
@RequestMapping("/model/file")
public class MdModelFileController extends BaseController
{
    @Autowired
    private IMdModelFileService mdModelFileService;


    /**
     * 查询模型文件信息列表
     */
    @ApiOperation("查询模型文件信息列表")
    @GetMapping("/list")
    public TableDataInfo list(MdModelFile mdModelFile)
    {
        startPage();
        List<MdModelFile> list = mdModelFileService.selectMdModelFileList(mdModelFile);
        return getDataTable(list);
    }

    /**
     * 导出模型文件信息列表
     */
    @ApiOperation("导出模型文件信息列表")
    @Log(title = "模型文件信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MdModelFile mdModelFile)
    {
        List<MdModelFile> list = mdModelFileService.selectMdModelFileList(mdModelFile);
        ExcelUtil<MdModelFile> util = new ExcelUtil<MdModelFile>(MdModelFile.class);
        util.exportExcel(response, list, "模型文件信息数据");
    }

    /**
     * 获取模型文件信息详细信息
     */
    @ApiOperation("获取模型文件信息详细信息")
    @GetMapping(value = "/{fileid}")
    public AjaxResult getInfo(@PathVariable("fileid") String fileid)
    {
        return success(mdModelFileService.selectMdModelFileByFileid(fileid));
    }

    /**
     * 新增模型文件信息
     */
    @ApiOperation("新增模型文件信息")
    @Log(title = "模型文件信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MdModelFile mdModelFile)
    {

        return toAjax(mdModelFileService.insertMdModelFile(mdModelFile));
    }

    /**
     * 修改模型文件信息
     */
    @ApiOperation("修改模型文件信息")
    @Log(title = "模型文件信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MdModelFile mdModelFile)
    {
        return toAjax(mdModelFileService.updateMdModelFile(mdModelFile));
    }

    /**
     * 删除模型文件信息
     */
    @ApiOperation("删除模型文件信息")
    @Log(title = "模型文件信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{fileids}")
    public AjaxResult remove(@PathVariable String[] fileids)
    {
        return toAjax(mdModelFileService.deleteMdModelFileByFileids(fileids));
    }
}
